'''
********************************************************************************
* Name: gsshapy
* Author: Nathan Swain
* Created On: Mar 18, 2013
* Copyright: (c) Brigham Young University 2013
* License: BSD 2-Clause
********************************************************************************
'''
def version():
    return '1.2.0'

